@@ -197,9 +197,10 @@ class EloquaBulkClient(object):
         return resp
 
     def make_request(self, **kwargs):
-        logger.info(u'{method} Request: {json}'.format(**kwargs))
-        if kwargs.get('json'):
-            logger.info('payload: {json}'.format(**kwargs))
+        if self.debug:
+            logger.info(u'{method} Request: {url}'.format(**kwargs))
+            if kwargs.get('json'):
+                logger.info('payload: {json}'.format(**kwargs))
 
         if self.auth_type == AuthType.OAUTH2:
             resp = self.oauth.request(**kwargs)
